import { MockPurchaseAPI } from "../purchase-mock-api";
import { mockDB } from "../db";

export async function createSamplePurchase() {
	const users = await mockDB.users.where("user_role").equals("customer").toArray();
	if (users.length === 0) throw new Error("No customers found");

	const user = users[Math.floor(Math.random() * users.length)];
	const products = await mockDB.products.toArray();
	if (products.length === 0) throw new Error("No products found");

	const entries = [];

	for (let i = 0; i < Math.floor(Math.random() * 3) + 1; i++) {
		const product = products[Math.floor(Math.random() * products.length)];
		const quantity = Math.floor(Math.random() * 4) + 1;

		entries.push({
			purchase_id: 0,
			product_id: product.id,
			product_variant_id: 0,
			quantity,
		});
	}

	if (entries.length === 0) throw new Error("No suitable product variants found");

	let total = 0;

	for (const entry of entries) {
		const product = await mockDB.products.get(entry.product_id);
		if (product) {
			total += product.price * entry.quantity;
		}
	}

	const coupons = await mockDB.coupons.toArray();
	const validCoupons = coupons.filter(
		(c) => new Date(c.valid_due) > new Date()
	);
	const useCoupon = validCoupons.length > 0 && Math.random() < 0.5;
	const chosenCoupon = useCoupon
		? validCoupons[Math.floor(Math.random() * validCoupons.length)]
		: null;

	const discountedTotal = chosenCoupon
		? Math.max(0, total - chosenCoupon.discount_amount)
		: total;

	// ✅ Generate a random date within the past year
	const now = new Date();
	const monthsAgo = Math.floor(Math.random() * 12); // 0–11 months ago
	const date = new Date(now.getFullYear(), now.getMonth() - monthsAgo, 1);

	const randomDay = Math.floor(Math.random() * 28) + 1;
	date.setDate(randomDay);
	const isoDate = date.toISOString();

	const purchase = await MockPurchaseAPI.createPurchase(
		{
			user_id: user.id,
			used_coupon_id: chosenCoupon?.id ?? null,
			date_purchased: isoDate,
			total: discountedTotal,
		},
		entries,
	);

	console.log(
		`Created mock purchase${chosenCoupon ? " with coupon" : ""} on ${date.toDateString()}:`,
		purchase,
	);
}
