import {
	Bar,
	BarChart,
	ResponsiveContainer,
	XAxis,
	YAxis,
} from "recharts";

interface OverviewProps {
	data: { name: string; total: number }[];
}

export function Overview({ data }: OverviewProps) {
	// Create labels for the past 12 months ending with current
	const monthFormatter = new Intl.DateTimeFormat("en-US", { month: "short" });
	const now = new Date();
	const past12Months = Array.from({ length: 12 }).map((_, i) => {
		const d = new Date(now.getFullYear(), now.getMonth() - (11 - i), 1);
		return monthFormatter.format(d);
	});

	const chartData = past12Months.map((month) => ({
		name: month,
		total: data.find((d) => d.name === month)?.total ?? 0,
	}));

	return (
		<ResponsiveContainer width="100%" height={350}>
			<BarChart data={chartData}>
				<XAxis
					dataKey="name"
					stroke="#888888"
					fontSize={12}
					tickLine={false}
					axisLine={false}
				/>
				<YAxis
					stroke="#888888"
					fontSize={12}
					tickLine={false}
					axisLine={false}
					tickFormatter={(value) => `$${value}`}
				/>
				<Bar
					dataKey="total"
					fill="currentColor"
					radius={[4, 4, 0, 0]}
					className="fill-primary"
				/>
			</BarChart>
		</ResponsiveContainer>
	);
}
